@@ -11,13 +11,14 @@
 #import "ZoomStory.h"
 #import "ZoomStoryID.h"
 
+// Notifications
+extern NSString* ZoomMetadataWillDestroyStory;			// A story with a particular ID will be destroyed
+
 // Cocoa interface to the C ifmetadata class
-// Yes, Panther now has a SAX parser. No, I'm not using it: I need Jaguar support.
-// (Plus I want to be able to port all of Zoom's backend to other platforms)
 
 @interface ZoomMetadata : NSObject {
 	NSString* filename;
-	struct IFMetadata* metadata;
+	struct IFMetabase* metadata;
 	
 	NSLock* dataLock;
 }
@@ -27,15 +28,23 @@
 - (id) initWithContentsOfFile: (NSString*) filename;	// Calls initWithData
 - (id) initWithData: (NSData*) xmlData;					// Designated initialiser
 
+// Thread safety [called by ZoomStory]
+- (void) lock;
+- (void) unlock;
+	
 // Information about the parse
 - (NSArray*) errors;
 
 // Retrieving information
-- (ZoomStory*) findStory: (ZoomStoryID*) ident;
+- (BOOL) containsStoryWithIdent: (ZoomStoryID*) ident;
+- (ZoomStory*) findOrCreateStory: (ZoomStoryID*) ident;
 - (NSArray*)   stories;
 
 // Storing information
-- (void) storeStory: (ZoomStory*) story;
+- (void) copyStory: (ZoomStory*) story;
+- (void) copyStory: (ZoomStory*) story
+			  toId: (ZoomStoryID*) copyID;
+- (void) removeStoryWithIdent: (ZoomStoryID*) ident;
 
 // Saving the file
 - (NSData*) xmlData;
